Plasticity Module
=================

.. currentmodule:: plastro.plasticity

The plasticity module provides core functions for simulating cellular plasticity through various mechanisms.

Core Functions
--------------

.. autosummary::
   :toctree: generated/

   random_walk_plasticity
   leiden_switch_plasticity
   subclone_switch_plasticity
   perform_random_walk
   visualize_walk

Utility Functions
-----------------

.. autosummary::
   :toctree: generated/

   construct_phenotypic_graph
   graph_from_connectivities
   get_distances_of_moves
   find_subclones

Function Details
----------------

.. automodule:: plastro.plasticity
   :members:
   :undoc-members:
   :show-inheritance: